import { useMutation, useQueryClient } from '@tanstack/react-query';

import { useUpdateTimestamp } from '@/features/library/backend/use-update-timestamp';

import { KEYS } from '@/backend/configuration';

import { ossApi } from './api';
import { type IOperationPosition } from './types';

export const useUpdateLayout = () => {
  const client = useQueryClient();
  const { updateTimestamp } = useUpdateTimestamp();
  const mutation = useMutation({
    mutationKey: [KEYS.global_mutation, ossApi.baseKey, 'update-layout'],
    mutationFn: ossApi.updateLayout,
    onSuccess: (_, variables) => updateTimestamp(variables.itemID),
    onError: () => client.invalidateQueries()
  });
  return {
    updateLayout: (data: {
      itemID: number; //
      positions: IOperationPosition[];
      isSilent?: boolean;
    }) => mutation.mutateAsync(data)
  };
};
